#
# spec file for package libpfm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define vname   libpfm4
Name:           libpfm
Version:        4.6.0
Release:        5.5
Summary:        Library to encode performance events
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://perfmon2.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  python-devel
BuildRequires:  swig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a library that can be used to encode events into the
format required by the operating systems performance monitoring subsystem.

%package -n %{vname}
Summary:        Runtime library to encode performance events for use by perf tool
Group:          System/Libraries

%description -n %{vname}
This package provides a library that can be used to encode events into the
format required by the operating systems performance monitoring subsystem.
The library does not make any performance monitoring system calls, it simply
provides a method to convert an event name, expressed as a string, to an event
encoding. The user of the library may use this event encoding in a subsequent
system call.

The current libpfm4 provides support for the perf_events interface which was
introduced in Linux v2.6.31.

%package        devel
Summary:        Development library to encode performance events for perf_events interface
Group:          Development/Libraries/C and C++
Requires:       %{vname} = %{version}

%description devel
This package provides development libraries and header files used to encode performance events for perf_events interface.

%package        devel-static
Summary:        Static library version of libpfm
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description devel-static
This package contains the static variant of libpfm.

%package -n     python-%{name}
Summary:        Python bindings for libpfm and perf_event_open system call
Group:          Development/Libraries/Python
Requires:       %{vname} = %{version}

%description -n python-%{name}
This package provides python bindings for the libpfm4 package and the perf_event_open system call.

%prep
%setup -q

%build
%global python_config CONFIG_PFMLIB_NOPYTHON=n
make %{?_smp_mflags} %{python_config}

%install
%global python_config CONFIG_PFMLIB_NOPYTHON=n PYTHON_PREFIX="%{buildroot}/%{py_prefix}"
make \
    PREFIX="%{buildroot}/%{_prefix}" \
    LIBDIR="%{buildroot}/%{_libdir}" \
    %{python_config} \
    LDCONFIG=/bin/true \
    install

# temp hack to fix rpmlint file-contains-buildroot for *.pyc
# http://lists.opensuse.org/opensuse-factory/2012-01/msg00235.html
find "%{buildroot}/%{python_sitearch}/" -name '*.pyc' -delete
python -c 'import compileall; compileall.compile_dir("%{buildroot}%{python_sitearch}/", ddir="%{python_sitearch}/", force=1)'

%post -n %{vname} -p /sbin/ldconfig

%postun	-n %{vname} -p /sbin/ldconfig

%files -n %{vname}
%defattr(644,root,root,755)
%doc README
%attr(755,root,root) %{_libdir}/lib*.so.*

%files devel
%defattr(644,root,root,755)
%{_includedir}/*
%{_mandir}/man3/*
%{_libdir}/lib*.so

%files devel-static
%defattr(-,root,root)
%{_libdir}/lib*.a

%files -n python-%{name}
%defattr(644,root,root,755)
%attr(755,root,root) %{python_sitearch}/*

%changelog
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 4.6.0 fate#318068:
  * Intel Broadwell (desktop core)
  * Intel Haswell-EP (core)
  * Applied Micro X-Gene processor
  * ARM A53 processor
  * Intel SNB, IVB, HSW event table updates
  * IBM Power8 event table updates
  * improved Intel x86 model detection
  * bug fixes and many other improvements
- Cleanup with spec-cleaner
- Drop obsolete patch:
  * libpfm-add-ibm-power8-support.patch
- Remove with_python switch that always evaluated as true
  * If the need is really here it should be used as %%bcond_without
* Mon Feb 16 2015 p.drouand@gmail.com
- Update to version 4.5.0
  * Intel IVB-EP uncore PMU support
  * Intel Silvermont support
  * Perf raw event syntax support
  * Intel RAPL event support
  * AMD Fam15h northbridge support
  * Qualcomm Krait support
  * IBM Power 8 support
  * IBM s390 updates
  * AMD Fam15h fixes
  * various IVB, SNB, HSW event table updates
  * more bug fixes
* Thu Jan  9 2014 tonyj@suse.com
- Add Power8 support (libpfm-add-ibm-power8-support.patch) FATE#315274
* Wed Dec  4 2013 tonyj@suse.com
- Update to version 4.4.
- Changelog:
  - Intel SandyBridge-EP uncore PMU support (all boxes)
  - Intel IvyBridge desktop core and uncore PMU support
  - Intel IvyBridge-EP core PMU support
  - newer Intel Haswell desktop core PMU support
  - newer Intel Atom
  - Intel Knigts Corner
  - Intel Nehalem, Westmere, SandyBridge, IvyBridge, Haswell PEBS Load Latency
    modifier (ldlat)
  - many bug fixes and other minor improvements
* Mon Jan 28 2013 dimstar@opensuse.org
- Add baselibs.conf: provide libpfm4 as -32bit (makes papi-32bit
  installable).
* Wed Jan  9 2013 pth@suse.de
- Run service to format spec file.
- Small cosmetic changes in spec file.
* Tue Jan  8 2013 tonyj@suse.com
- Changes to python builds, drop duplicate defns already in system macros.
- Fix build when with_python=0
* Fri Jan  4 2013 jengelh@inai.de
- Parallel build, remove redundant %%clean section, consistent use
  of %%buildroot
- Follow python package naming guidelines
- Separate out static library into distinct subpackage
* Sat Dec 29 2012 tonyj@suse.com
- Initial checkin of libpfm4 (version 4.3).
